@@ -1,15 +1,15 @@
 <?php
 declare(encoding = 'utf-8');
-require_once 'person.php';
+require_once 'Person.php';
 require_once 'CA.php';
 require_once 'key_sign.php';
 require_once 'db_query.php';
-require_once 'mdb2_wrapper.php';
+require_once 'MDB2Wrapper.php';
 require_once 'CGE_ComodoAPIException.php';
 require_once 'confusa_constants.php';
 require_once 'CGE_ComodoCredentialException.php';
-require_once 'curlwrapper.php';
-require_once 'Confusa_Session.php';
+require_once 'CurlWrapper.php';
+require_once 'CS.php';
 
 /**
  * CA_Comodo. Comodo signing extension for CA.
@@ -73,7 +73,7 @@ class CA_Comodo extends CA
 			);
 	}
 	try {
-		$errorCode = create_pw(8);
+		$errorCode = PW::create(8);
 		$errorMsg = "[$errorCode] " . __FILE__ . ":" . __LINE__ . " ";
 
 		$res = MDB2Wrapper::execute($login_cred_query, array('text'),
@@ -259,8 +259,11 @@ class CA_Comodo extends CA
 		$this->capiAuthorizeCSR();
 
 		$this->cacheInvalidate();
+		$timezone = new DateTimeZone($this->person->getTimezone());
+		$dt = new DateTime("now", $timezone);
+
 		CA::sendMailNotification($this->order_number,
-		                         date('Y-m-d H:i T'),
+		                         $dt->format('Y-m-d H:i T'),
 		                         $_SERVER['REMOTE_ADDR'],
 		                         $this->person,
 		                         $this->getFullDN());
@@ -308,8 +311,12 @@ class CA_Comodo extends CA
 
 		$this->capiAuthorizeCSR();
 		$this->cacheInvalidate();
+
+		$timezone = new DateTimeZone($this->person->getTimezone());
+		$dt = new DateTime("now", $timezone);
+
 		CA::sendMailNotification($this->order_number,
-		                         date('Y-m-d H:i T'),
+		                         $dt->format('Y-m-d H:i T'),
 		                         $_SERVER['REMOTE_ADDR'],
 		                         $this->person,
 								 $this->getFullDN());
@@ -366,16 +373,17 @@ class CA_Comodo extends CA
 			}
 		}
 
-        $common_name = $this->person->getX509ValidCN();
+        $uid = $this->person->getEPPN();
         $organization = 'O=' . $this->person->getSubscriber()->getOrgName();
 
-        $params = $this->capiGetCertList($common_name, $days);
+        $params = $this->capiGetEPPNCertList($uid, $days);
         $res=array();
 		$dates = array();
 		/* initiallize the array with a high value, so that the cache stays
 		 * valid very long if there are no certificates at all (ordering a
 		 * cert will invalidate it anyways) */
 		$dates[] = time();
+		$timezone = new DateTimeZone($this->person->getTimezone());
 
         /* transfer the orders from the string representation in the response
          * to the array representation we use internally */
@@ -403,12 +411,14 @@ class CA_Comodo extends CA
 			if (isset($params[$i . '_1_notAfter'])) {
 				/* for simplicity, format the time just as an SQL server would return it */
 				$valid_untill = $params[$i . '_1_notAfter'];
-				$valid_untill = date('Y-m-d H:i:s', $valid_untill);
+				$dt = new DateTime("@$valid_untill");
+				$dt->setTimezone($timezone);
+				$valid_untill = $dt->format('Y-m-d H:i:s T');
 				$res[$i-1]['valid_untill'] = $valid_untill;
 			}
 
             $res[$i-1]['order_number'] = $params[$i . '_orderNumber'];
-            $res[$i-1]['cert_owner'] = $this->person->getX509ValidCN();
+            $res[$i-1]['cert_owner'] = stripslashes($this->person->getX509ValidCN());
 			$res[$i-1]['status'] = $status;
 
 			if (isset($params[$i . '_1_notBefore'])) {
@@ -704,7 +714,7 @@ class CA_Comodo extends CA
 
         $return_res = NULL;
 
-        Logger::log_event(LOG_NOTICE, "Trying to revoke certificate with order number " .
+        Logger::log_event(LOG_NOTICE, "Revoking certificate with order number " .
                                       $key .
                                       " using Comodo's auto-revoke-API. Sending to user with ip " .
                                       $_SERVER['REMOTE_ADDR']);
@@ -719,16 +729,17 @@ class CA_Comodo extends CA
 
         /* will not revoke test certificates? */
         if (Config::get_config('capi_test')) {
-            $postfields_revoke["test"] = 'Y';
+		Logger::log_event(LOG_DEBUG, "CA_C: in test-mode");
+		$postfields_revoke["test"] = 'Y';
         }
-
-		$data = CurlWrapper::curlContact($revoke_endpoint, "post", $postfields_revoke);
+	$data = CurlWrapper::curlContact($revoke_endpoint, "post", $postfields_revoke);
 
         /* try to catch all kinds of errors that can happen when connecting */
         if ($data === FALSE) {
-            throw new CGE_ComodoAPIException("Could not connect to revoke-API! " .
-                                        "Check Confusa configuration!\n"
-            );
+		Logger::log_event(LOG_NOTICE, "[CA_C]: Could not connect to revoke-API. Check configuration.");
+		throw new CGE_ComodoAPIException("Could not connect to revoke-API! " .
+						 "Check Confusa configuration!\n"
+			);
         } else {
 			$error_parts = explode("\n", $data, 2);
 			$STATUS_OK = "0";
@@ -881,8 +892,8 @@ class CA_Comodo extends CA
 
 	private function capiGetEPPNCertList($eppn, $days)
 	{
-		Logger::log_event(LOG_DEBUG, "Trying to the the list with the certificates " .
-		                             "for eppn $eppn");
+		Logger::log_event(LOG_DEBUG, "Trying to get the the list of the certificates " .
+		                             "for user $eppn");
 		$list_endpoint = ConfusaConstants::$CAPI_LISTING_ENDPOINT;
 		$postfields_list["loginName"]		= $this->login_name;
 		$postfields_list["loginPassword"]	= $this->login_pw;
@@ -910,17 +921,17 @@ class CA_Comodo extends CA
 			$msg .= "Perhaps some configuration-switch is not properly set.";
 			$msg .= "Server gave no error-code.";
 			throw new CGE_ComodoAPIException($msg);
-        }
+		}
 
-        if ($params['errorCode'] == "0") {
-            return $params;
-        } else {
+		if ($params['errorCode'] == "0") {
+			return $params;
+		} else {
 			$msg = $this->capiErrorMessage($params['errorCode'], $params['errorMessage']);
 			throw new CGE_ComodoAPIException("Received error when trying to list " .
 			                                 "certificates from the remote-API: " .
 			                                 $params['errorMessage'] . $msg
-            );
-        }
+				);
+		}
 	} /* end capiGetEPPNCertList */
 
     /*
@@ -1088,7 +1099,8 @@ class CA_Comodo extends CA
 
 		/* manually compose the subject. Necessary, because we want to have
          * Terena domainComponents */
-        $postfields_sign_req["subject_commonName_$pf_counter"] = $this->person->getX509ValidCN();
+        $postfields_sign_req["subject_commonName_$pf_counter"] =
+		stripslashes($this->person->getX509ValidCN());
 		$pf_counter++;
 
         $postfields_sign_req["subject_organizationName_".$pf_counter++] = $orgName;
@@ -1115,7 +1127,7 @@ class CA_Comodo extends CA
 		if (isset($params['errorItem'])) {
 			$msg .= " " . $params['errorItem'];
 		}
-		$this->capiErrorMessage($params['errorCode'], $params['errorMessage']);
+		$msg .= $this->capiErrorMessage($params['errorCode'], $params['errorMessage']);
 		throw new CGE_ComodoAPIException($msg);
         }
 
@@ -1133,7 +1145,7 @@ class CA_Comodo extends CA
                                         "order number " .
                                         $this->order_number .
                                         " for user " .
-                                        $this->person->getX509ValidCN() .
+                                        stripslashes($this->person->getX509ValidCN()) .
                                         " Person contacted us from " .
                                         $_SERVER['REMOTE_ADDR']);
 
@@ -1253,7 +1265,7 @@ class CA_Comodo extends CA
                               array('text'),
                               array($this->order_number));
           Logger::log_event(LOG_NOTICE, "Authorized remote certificate for person ".
-                                        $this->person->getX509ValidCN().
+                                        stripslashes($this->person->getX509ValidCN()).
                                         " with order number " .
                                         $this->order_number .
                                         " Person contacted us from ".
