@@ -1,10 +1,11 @@
 <?php
 require_once 'confusa_include.php';
-include_once 'framework.php';
-include_once 'mdb2_wrapper.php';
+require_once 'Content_Page.php';
+include_once 'Framework.php';
+include_once 'MDB2Wrapper.php';
 include_once 'db_query.php';
-include_once 'logger.php';
-include_once 'input.php';
+include_once 'Logger.php';
+include_once 'Input.php';
 
 
 /**
@@ -53,7 +54,14 @@ class CP_Admin extends Content_Page
 					break;
 				case 'add_nren_admin':
 					$admin = Input::sanitizeEPPN($_POST['nren_admin']);
-					$this->addNRENAdmin($admin);
+					$idp = Input::sanitizeIdPName($_POST['idp']);
+
+					if ($idp === '-') {
+						$this->addNRENAdmin($admin, NULL);
+					} else {
+						$this->addNRENAdmin($admin, $idp);
+					}
+
 					break;
 				case 'delete_subs_admin':
 					$admin = Input::sanitizeEPPN($_POST['subs_admin']);
@@ -117,7 +125,7 @@ class CP_Admin extends Content_Page
 	{
 		/* IF user is not an admin, we stop here */
 		if (!($this->person->isAdmin())) {
-			Logger::log_event(LOG_NOTICE, "User " . $this->person->getX509ValidCN() . " was rejected at the admin-interface");
+			Logger::log_event(LOG_NOTICE, "User " . stripslashes($this->person->getX509ValidCN()) . " was rejected at the admin-interface");
 			$this->tpl->assign('reason', 'You do not have sufficient rights to view this page');
 			$this->tpl->assign('content', $this->tpl->fetch('restricted_access.tpl'));
 			return false;
@@ -147,7 +155,7 @@ class CP_Admin extends Content_Page
 	private function getNRENAdmins($nren)
 	{
 
-		$query  = "SELECT admin, admin_name, admin_email ";
+		$query  = "SELECT admin, admin_name, admin_email, idp_url ";
 		$query .= "FROM admins WHERE admin_level='2' AND nren=?";
 
 		$nrenID = $nren->getID();
@@ -174,7 +182,8 @@ class CP_Admin extends Content_Page
 			foreach($res as $row) {
 				$admins[] =  array('eppn' => $row['admin'],
 				                   'name' => $row['admin_name'],
-				                   'email' => $row['admin_email']);
+				                   'email' => $row['admin_email'],
+				                   'idp_url' => $row['idp_url']);
 			}
 		}
 
@@ -235,10 +244,10 @@ class CP_Admin extends Content_Page
 	/**
 	 * addNRENAdmin() add a new NREN administrator to the admin-table.
 	 *
-	 * @param String The unique name of the new admin (typically ePPN).
-	 * @param String The name of the NREN for the new administrator.
+	 * @param $admin string The unique name of the new admin (typically ePPN).
+	 * @param $idp string The IdP that the new admin should be associatied with
 	 */
-	private function addNRENAdmin($admin) {
+	private function addNRENAdmin($admin, $idp) {
 		if (!isset($admin)) {
 			Framework::error_output("Need to have the name of the new admin in order to add a new NREN-admin!");
 			return;
@@ -261,9 +270,9 @@ class CP_Admin extends Content_Page
 				return;
 			}
 
-			MDB2Wrapper::update("INSERT INTO admins (admin, admin_level, last_mode, nren) VALUES(?,?,?,?)",
-					    array('text', 'text', 'text', 'Integer'),
-					    array($admin, '2', '0', $nrenID));
+			MDB2Wrapper::update("INSERT INTO admins (admin, admin_level, last_mode, nren, idp_url) VALUES(?,?,?,?,?)",
+					    array('text', 'text', 'text', 'Integer', 'text'),
+					    array($admin, '2', '0', $nrenID, $idp));
 		} catch (DBStatementException $dbse) {
 			Framework::error_output("Problem with statement, probably server-issues. Server said " .
 			                        htmlentities($dbse->getMessage()));
@@ -325,8 +334,13 @@ class CP_Admin extends Content_Page
 				$this->tpl->assign('has_adm_entl',false);
 			}
 
+			$nren = $this->person->getNREN();
+			$idpList = $nren->getIdPList();
+			/* append an empty entry to the beginning */
+			$idpList = array_merge((array)'-', $idpList);
+			$this->tpl->assign('idps', $idpList);
 			$this->tpl->assign('nren_admins', $admins);
-			$this->tpl->assign('nren', $this->person->getNREN());
+			$this->tpl->assign('nren', $nren);
 			$this->tpl->assign('subscribers', $subscribers);
 	}
 
@@ -375,7 +389,7 @@ class CP_Admin extends Content_Page
 	 * This function will take the $admin and add it as a new
 	 * subscriber-admin. Given that the user has the admin-entitlement set.
 	 *
-	 * @param String admin	The ePPN of the admin to add
+	 * @param String admin	The unique identifier (e.g. ePPN) of the admin to add
 	 * @param String level	Subscriber-admin level (either subscribera-admin
 	 *			or sub-admin).
 	 * @param subscriberID integer The ID of the subscriber as exported by
@@ -566,7 +580,7 @@ class CP_Admin extends Content_Page
 	/**
 	 * ugradeSubscriberAdmin() Upgrade an admin from subscriber to NREN
 	 *
-	 * @param String admin the ePPN of the admin to upgrade
+	 * @param String admin the unique identifier (e.g. eppn) of the admin to upgrade
 	 *
 	 * @return void
 	 */
@@ -603,7 +617,7 @@ class CP_Admin extends Content_Page
 	/*
 	 * "Upgrade" a subscriber-sub-admin to a subscriber admin
 	 *
-	 * @param $admin The ePPN of the admin
+	 * @param $admin The unique identifier (e.g. eppn) of the admin
 	 * @param $subscriberID integer The ID of the subscriber within which everything happens
 	 */
 	private function upgradeSubscriberSubAdmin($admin, $subscriberID)
