@@ -1,16 +1,17 @@
 <?php
 require_once 'confusa_include.php';
-require_once 'framework.php';
-require_once 'mdb2_wrapper.php';
-require_once 'logger.php';
+require_once 'Content_Page.php';
+require_once 'Framework.php';
+require_once 'MDB2Wrapper.php';
+require_once 'Logger.php';
 require_once 'csr_lib.php';
 require_once 'file_upload.php';
-require_once 'config.php';
+require_once 'Config.php';
 require_once 'send_element.php';
-require_once 'input.php';
-require_once 'output.php';
-require_once 'permission.php';
-require_once 'Confusa_Session.php';
+require_once 'Input.php';
+require_once 'Output.php';
+require_once 'Permission.php';
+require_once 'CS.php';
 
 /**
  * ProcessCsr - the web frontend for handling of CSRs
@@ -42,8 +43,9 @@ final class CP_ProcessCsr extends Content_Page
 		parent::pre_process($person);
 		$res = false;
 
+		$subscriber = $this->person->getSubscriber();
 		/* Test subscriber-status: */
-		if (!$this->person->getSubscriber()->isSubscribed()) {
+		if (empty($subscriber) || !$subscriber->isSubscribed()) {
 			return false;
 		}
 
@@ -84,14 +86,14 @@ final class CP_ProcessCsr extends Content_Page
 			/* assign the order_number again */
 			$this->tpl->assign('order_number', $order_number);
 			$this->tpl->assign('status_poll', true);
-
+			$this->tpl->assign('ganticsrf', "anticsrf=".Input::sanitizeAntiCSRFToken($_GET['anticsrf']));
 			if ($this->ca->pollCertStatus($order_number)) {
 			    $this->tpl->assign('done', TRUE);
 			}
 
 		} else if (isset($_GET['install_cert'])) {
 			$order_number = Input::sanitizeCertKey($_GET['install_cert']);
-			$ua = getUserAgent();
+			$ua = Output::getUserAgent();
 			$script = $this->ca->getCertDeploymentScript($order_number, $ua);
 
 			if ($ua == "keygen") {
@@ -112,7 +114,7 @@ final class CP_ProcessCsr extends Content_Page
 			$request = trim($request);
 			if (!empty($request)) {
 				try {
-					$order_number = $this->approveBrowserGenerated($request, getUserAgent());
+					$order_number = $this->approveBrowserGenerated($request, Output::getUserAgent());
 					$this->tpl->assign('order_number', $order_number);
 				} catch (KeySignException $kse) {
 					Framework::error_output($this->translateTag('l10n_sign_error', 'processcsr')
@@ -131,7 +133,10 @@ final class CP_ProcessCsr extends Content_Page
 
 	public function process()
 	{
-		if (!$this->person->getSubscriber()->isSubscribed()) {
+
+		$subscriber = $this->person->getSubscriber();
+
+		if (empty($subscriber) || !$subscriber->isSubscribed()) {
 			$this->tpl->assign('not_subscribed_header',
 					   $this->translateTag('l10n_not_sub_header', 'messages'));
 			$this->tpl->assign('not_subscribed_1',
@@ -141,6 +146,13 @@ final class CP_ProcessCsr extends Content_Page
 			$this->tpl->assign('content', $this->tpl->fetch('errors/unsubscribed.tpl'));
 			return;
 		}
+
+		if (Config::get_config('cert_product') == PRD_ESCIENCE) {
+			$this->tpl->assign('cps', ConfusaConstants::$LINK_ESCIENCE_CPS);
+		} else {
+			$this->tpl->assign('cps', ConfusaConstants::$LINK_PERSONAL_CPS);
+		}
+
 		$this->processDBCsr();
 		/* Set default-values to false to avoid warnings */
 		$this->tpl->assign('approve_csr', false);
@@ -148,11 +160,6 @@ final class CP_ProcessCsr extends Content_Page
 		$this->tpl->assign('upload_csr',  false);
 		$this->tpl->assign('paste_csr',   false);
 		$this->tpl->assign('aup_box_checked', $this->aup_set);
-		$this->tpl->assign('l10n_pcsr_email_table_summary',
-				   $this->translateTag('l10n_pcsr_email_table_summary', 'processcsr'));
-
-		$this->tpl->assign('l10n_privacy_notice_header',
-				   $this->translateTag('l10n_privacy_notice_header', 'messages'));
 		$this->tpl->assign('privacy_notice_text', $this->person->getNREN()->getPrivacyNotice($this->person));
 		$this->tpl->assign('finalDN',   $this->ca->getFullDN());
 
@@ -246,15 +253,6 @@ final class CP_ProcessCsr extends Content_Page
 		/* showing the normal UI */
 		$user_cert_enabled = $this->person->testEntitlementAttribute(Config::get_config('entitlement_user'));
 		$this->tpl->assign('user_cert_enabled', $user_cert_enabled);
-		/* get the UAP-tags */
-		$this->tpl->assign('csr_aup_title',
-				   $this->translateMessageTag('csr_aup_title'));
-		$this->tpl->assign('csr_aup_agreement',
-				   $this->translateMessageTag('csr_aup_agreement'));
-		$this->tpl->assign('csr_aup_info_short',
-				   $this->translateMessageTag('csr_aup_info_short'));
-		$this->tpl->assign('csr_aup_info_long',
-				   $this->translateMessageTag('csr_aup_info_long'));
 
 		/* decide which page to view */
 		if (array_key_exists('show', $_GET) &&  !is_null($_GET['show'])) {
@@ -332,9 +330,10 @@ final class CP_ProcessCsr extends Content_Page
 						    array('text', 'text', 'text', 'text'),
 						    array($csr, $ip, $this->person->getX509ValidCN(), $authvar));
 
-				$logmsg  = __FILE__ . " Inserted new CSR from $ip (" . $this->person->getX509ValidCN();
-				$logmsg .=") with hash " . pubkey_hash($csr, true);
-				Logger::log_event(LOG_INFO, $logmsg);
+				$logmsg  = "Inserted new CSR from $ip (" . stripslashes($this->person->getX509ValidCN());
+				$logmsg .= ") with hash " . pubkey_hash($csr, true);
+				Logger::logEvent(LOG_INFO, "Process_CSR", "processUploadedCSR()",
+				                 $logmsg);
 			}
 		}
 
@@ -373,9 +372,11 @@ final class CP_ProcessCsr extends Content_Page
 			} catch (ConfusaGenException $cge) {
 				$msg = "Too menu returns received. This can indicate database inconsistency.";
 				Framework::error_output($msg);
-				Logger::log_event(LOG_ALERT, "Several identical CSRs (" .
-						  $auth_token . ") exists in the database for user " .
-						  $this->person->getX509ValidCN());
+				Logger::logEvent(LOG_ALERT, "Process_CSR", "processDBCSR()",
+				                 "Several identical CSRs (" .
+				                 $auth_token . ") exists in the database for user " .
+				                 stripslashes($this->person->getX509ValidCN()),
+				                 __LINE__);
 				return;
 			}
 		}
@@ -413,9 +414,12 @@ final class CP_ProcessCsr extends Content_Page
 		try  {
 			$csr = get_csr_from_db($this->person, $authToken);
 		} catch (ConfusaGenException $e) {
-			Framework::error_output("Too many hits. Database incosistency.");
-			Logger::log_event(LOG_ALERT, $this->person->getX509ValidCN() .
-					  " tried to find CSR with key $authToken which resulted in multiple hits");
+			$errorTag = PW::create();
+			Framework::error_output("[$errorTag] Too many hits. Database incosistency.");
+			Logger::logEvent(LOG_ALERT, "Process_CSR", "approveCSR($authToken)",
+			                 stripslashes($this->person->getX509ValidCN()) .
+			                 " tried to find CSR with key $authToken which resulted in multiple hits",
+			                 __LINE__, $errorTag);
 			return false;
 		} catch (CSRNotFoundException $csrnfe) {
 			Framework::error_output("CSR not found, are you sure this is your CSR?\n");
@@ -423,10 +427,12 @@ final class CP_ProcessCsr extends Content_Page
 		}
 
 		if (!isset($csr)) {
-			Framework::error_output("Did not find CSR with auth_token " . htmlentities($auth_token));
+			$errorTag = PW::create();
+			Framework::error_output("[$errorTag] Did not find CSR with auth_token " . htmlentities($auth_token));
 			$msg  = "User " . $this->person->getEPPN() . " ";
 			$msg .= "tried to delete CSR with auth_token " . $authToken . " but was unsuccessful";
-			Logger::log_event(LOG_NOTICE, $msg);
+			Logger::logEvent(LOG_NOTICE, "Process_CSR", "approveCSR($authToken)",
+			                 $msg, __LINE__, $errorTag);
 			return false;
 		}
 
@@ -469,9 +475,11 @@ final class CP_ProcessCsr extends Content_Page
 		$url = "http";
 		if ($_SERVER['SERVER_PORT'] == 443)
 			$url .= "s";
-		$url .= "://" . $_SERVER['HTTP_HOST'] . "/" . dirname($_SERVER['PHP_SELF']) . "/download_certificate.php?poll=$authToken";
+		$url .= "://" . $_SERVER['HTTP_HOST'] . "/" . dirname($_SERVER['PHP_SELF']) .
+			"/download_certificate.php?poll=$authToken" .
+			"&amp;anticsrf=" . Framework::getAntiCSRF();
 		return "<META HTTP-EQUIV=\"REFRESH\" content=\"3; url=$url\">\n";
-	} /* end approve_csr_remote() */
+	} /* end approveCSR() */
 
 
 	/**
@@ -488,7 +496,7 @@ final class CP_ProcessCsr extends Content_Page
 					    $this->person->getX509ValidCN());
 		/* Format the IPs */
 		foreach ($res as $key => $value) {
-			$res[$key]['from_ip'] = format_ip($value['from_ip'], true);
+			$res[$key]['from_ip'] = Output::formatIP($value['from_ip'], true);
 		}
 		return $res;
 	}
@@ -498,7 +506,7 @@ final class CP_ProcessCsr extends Content_Page
 	 */
 	private function dispatchBrowserTemplate()
 	{
-		$ua = getUserAgent();
+		$ua = Output::getUserAgent();
 
 		switch($ua) {
 		case "msie_post_vista":
